/// <reference types="@welldone-software/why-did-you-render" />
import React, { CSSProperties, HTMLAttributes, MouseEvent as ReactMouseEvent, WheelEvent, FunctionComponent } from 'react';
import { OnSelectionChangeFunc, NodeTypesType, EdgeTypesType, OnLoad, Node, Edge, ConnectionMode, ConnectionLineType, ConnectionLineComponent, FlowTransform, OnConnectStart, OnConnectStop, OnConnectEnd, OnConnect, CoordinateExtent, KeyCode, PanOnScrollMode, OnEdgeUpdateFunc, NodeChange, EdgeChange } from '../../types';
import '../../style.css';
import '../../theme-default.css';
export interface ReactFlowProps extends Omit<HTMLAttributes<HTMLDivElement>, 'onLoad'> {
    nodes: Node[];
    edges: Edge[];
    onNodesChange?: (nodeChanges: NodeChange[]) => void;
    onEdgesChange?: (edgeChanges: EdgeChange[]) => void;
    onNodeClick?: (event: React.MouseEvent, node: Node) => void;
    onEdgeClick?: (event: React.MouseEvent, node: Edge) => void;
    onNodeDoubleClick?: (event: ReactMouseEvent, node: Node) => void;
    onNodeMouseEnter?: (event: ReactMouseEvent, node: Node) => void;
    onNodeMouseMove?: (event: ReactMouseEvent, node: Node) => void;
    onNodeMouseLeave?: (event: ReactMouseEvent, node: Node) => void;
    onNodeContextMenu?: (event: ReactMouseEvent, node: Node) => void;
    onNodeDragStart?: (event: ReactMouseEvent, node: Node) => void;
    onNodeDrag?: (event: ReactMouseEvent, node: Node) => void;
    onNodeDragStop?: (event: ReactMouseEvent, node: Node) => void;
    onConnect?: OnConnect;
    onConnectStart?: OnConnectStart;
    onConnectStop?: OnConnectStop;
    onConnectEnd?: OnConnectEnd;
    onLoad?: OnLoad;
    onMove?: (flowTransform?: FlowTransform) => void;
    onMoveStart?: (flowTransform?: FlowTransform) => void;
    onMoveEnd?: (flowTransform?: FlowTransform) => void;
    onSelectionChange?: OnSelectionChangeFunc;
    onSelectionDragStart?: (event: ReactMouseEvent, nodes: Node[]) => void;
    onSelectionDrag?: (event: ReactMouseEvent, nodes: Node[]) => void;
    onSelectionDragStop?: (event: ReactMouseEvent, nodes: Node[]) => void;
    onSelectionContextMenu?: (event: ReactMouseEvent, nodes: Node[]) => void;
    onPaneScroll?: (event?: WheelEvent) => void;
    onPaneClick?: (event: ReactMouseEvent) => void;
    onPaneContextMenu?: (event: ReactMouseEvent) => void;
    nodeTypes?: NodeTypesType;
    edgeTypes?: EdgeTypesType;
    connectionMode?: ConnectionMode;
    connectionLineType?: ConnectionLineType;
    connectionLineStyle?: CSSProperties;
    connectionLineComponent?: ConnectionLineComponent;
    deleteKeyCode?: KeyCode;
    selectionKeyCode?: KeyCode;
    multiSelectionKeyCode?: KeyCode;
    zoomActivationKeyCode?: KeyCode;
    snapToGrid?: boolean;
    snapGrid?: [number, number];
    onlyRenderVisibleElements?: boolean;
    nodesDraggable?: boolean;
    nodesConnectable?: boolean;
    elementsSelectable?: boolean;
    selectNodesOnDrag?: boolean;
    paneMoveable?: boolean;
    minZoom?: number;
    maxZoom?: number;
    defaultZoom?: number;
    defaultPosition?: [number, number];
    translateExtent?: CoordinateExtent;
    preventScrolling?: boolean;
    nodeExtent?: CoordinateExtent;
    defaultMarkerColor?: string;
    zoomOnScroll?: boolean;
    zoomOnPinch?: boolean;
    panOnScroll?: boolean;
    panOnScrollSpeed?: number;
    panOnScrollMode?: PanOnScrollMode;
    zoomOnDoubleClick?: boolean;
    onEdgeUpdate?: OnEdgeUpdateFunc;
    onEdgeContextMenu?: (event: ReactMouseEvent, edge: Edge) => void;
    onEdgeMouseEnter?: (event: ReactMouseEvent, edge: Edge) => void;
    onEdgeMouseMove?: (event: ReactMouseEvent, edge: Edge) => void;
    onEdgeMouseLeave?: (event: ReactMouseEvent, edge: Edge) => void;
    onEdgeDoubleClick?: (event: ReactMouseEvent, edge: Edge) => void;
    onEdgeUpdateStart?: (event: ReactMouseEvent, edge: Edge) => void;
    onEdgeUpdateEnd?: (event: MouseEvent, edge: Edge) => void;
    edgeUpdaterRadius?: number;
    noDragClassName?: string;
    noWheelClassName?: string;
    noPanClassName?: string;
}
export declare type ReactFlowRefType = HTMLDivElement;
declare const ReactFlow: FunctionComponent<ReactFlowProps>;
export default ReactFlow;
