import { CSSProperties, MouseEvent as ReactMouseEvent } from 'react';
import { SnapGrid } from './general';
import { XYPosition, Position, CoordinateExtent } from './utils';
import { HandleElement } from './handles';
export interface Node<T = any> {
    id: string;
    position: XYPosition;
    type?: string;
    data?: T;
    style?: CSSProperties;
    className?: string;
    targetPosition?: Position;
    sourcePosition?: Position;
    hidden?: boolean;
    selected?: boolean;
    dragging?: boolean;
    draggable?: boolean;
    selectable?: boolean;
    connectable?: boolean;
    dragHandle?: string;
    width?: number | null;
    height?: number | null;
    parentNode?: string;
    zIndex?: number;
    extent?: 'parent' | CoordinateExtent;
}
export interface NodeProps<T = any> {
    id: string;
    type: string;
    data: T;
    selected: boolean;
    isConnectable: boolean;
    xPos: number;
    yPos: number;
    dragging: boolean;
    zIndex: number;
    targetPosition?: Position;
    sourcePosition?: Position;
    dragHandle?: string;
}
export declare type NodeMouseHandler = (event: ReactMouseEvent, node: Node) => void;
export interface WrapNodeProps<T = any> {
    id: string;
    type: string;
    data: T;
    selected: boolean;
    isConnectable: boolean;
    scale: number;
    xPos: number;
    yPos: number;
    width?: number | null;
    height?: number | null;
    isSelectable: boolean;
    isDraggable: boolean;
    selectNodesOnDrag: boolean;
    onClick?: NodeMouseHandler;
    onNodeDoubleClick?: NodeMouseHandler;
    onMouseEnter?: NodeMouseHandler;
    onMouseMove?: NodeMouseHandler;
    onMouseLeave?: NodeMouseHandler;
    onContextMenu?: NodeMouseHandler;
    onNodeDragStart?: NodeMouseHandler;
    onNodeDrag?: NodeMouseHandler;
    onNodeDragStop?: NodeMouseHandler;
    style?: CSSProperties;
    className?: string;
    sourcePosition?: Position;
    targetPosition?: Position;
    hidden?: boolean;
    isInitialized?: boolean;
    snapToGrid?: boolean;
    snapGrid?: SnapGrid;
    dragging: boolean;
    resizeObserver: ResizeObserver | null;
    dragHandle?: string;
    zIndex: number;
    isParent: boolean;
    noPanClassName: string;
    noDragClassName: string;
}
export declare type NodeHandleBounds = {
    source: HandleElement[] | null;
    target: HandleElement[] | null;
};
export declare type NodeDiffUpdate = {
    id?: string;
    diff?: XYPosition;
    dragging?: boolean;
};
export declare type NodeDimensionUpdate = {
    id: string;
    nodeElement: HTMLDivElement;
    forceUpdate?: boolean;
};
export declare type NodeInternalsItem = Node & {
    positionAbsolute: XYPosition;
    z: number;
    handleBounds?: NodeHandleBounds;
    isParent?: boolean;
};
export declare type NodeInternals = Map<string, NodeInternalsItem>;
